==> datanucleus-core-2.0.3-sources.jar: org/datanucleus/store/mapped/scostore/FKListStoreSpecialization.java <==
/**********************************************************************
 Copyright (c) 2007 Andy Jefferson and others. All rights reserved.
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 Contributors:
 ...
 **********************************************************************/
package org.datanucleus.store.mapped.scostore;

import org.datanucleus.ObjectManager;
import org.datanucleus.StateManager;

/**
 * Specialization interface for {@link FKListStore}. {@link FKListStore} delegates to instances of this interface for
 * behavior that is tied to a specific datastore implementation.
 */
public interface FKListStoreSpecialization extends AbstractListStoreSpecialization
{
    Object set(StateManager sm, int index, Object element, boolean allowDependentField, 
            ElementContainerStore ecs, Object o);

    boolean updateElementFk(StateManager sm, Object element, Object owner, int index, ObjectManager om, 
            ElementContainerStore ecs);

    void clearWithoutDelete(ObjectManager om, StateManager ownerSM, ElementContainerStore ecs);

    void removeAt(StateManager sm, int index, int size, boolean nullify, FKListStore fkListStore);
}

==> datanucleus-core-2.2.2-sources.jar: org/datanucleus/store/mapped/scostore/FKListStoreSpecialization.java <==
/**********************************************************************
 Copyright (c) 2007 Andy Jefferson and others. All rights reserved.
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 Contributors:
 ...
 **********************************************************************/
package org.datanucleus.store.mapped.scostore;

import org.datanucleus.store.ExecutionContext;
import org.datanucleus.store.ObjectProvider;

/**
 * Specialization interface for {@link FKListStore}. {@link FKListStore} delegates to instances of this interface for
 * behavior that is tied to a specific datastore implementation.
 */
public interface FKListStoreSpecialization extends AbstractListStoreSpecialization
{
    Object set(ObjectProvider sm, int index, Object element, boolean allowDependentField, 
            ElementContainerStore ecs, Object o);

    boolean updateElementFk(ObjectProvider sm, Object element, Object owner, int index, ExecutionContext ec, 
            ElementContainerStore ecs);

    void clearWithoutDelete(ExecutionContext ec, ObjectProvider ownerSM, ElementContainerStore ecs);

    void removeAt(ObjectProvider sm, int index, int size, boolean nullify, FKListStore fkListStore);
}
